cmsm - A Python module for core-set Markov-state model (csMSM) estimation — cnnclustering documentation

# cmsm - A Python module for core-set Markov-state model (csMSM) estimation

## cmsm - A Python module for coreset Markov-state model estimation

class `cnnclustering.cmsm.` `CMSM`(dtrajs=None, T=None, unit='ps', step=1)

  Core set MSM class

  `cmsm`(dtrajs=None, lag=1, minlenfactor=10, v=True, correct=False, trim=0, ignore_states=None)

    Estimate coreset markov model from characteristic functions at a given lagtime

  `get_connected_sets`(T, largest='cluster_count', v=True)

    largest: None, ‘cluster_count’, ‘point_count’

  `get_milestoning`(dtraj)

    Neglect transitions to noise as state transition